/****************************************************************************
 *
 *  Copyright (c) 2012, EBM WebSourcing
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

package org.ow2.petals.admin.jmx.artifact;

import java.net.URL;

import org.ow2.petals.admin.api.artifact.SharedLibrary;
import org.ow2.petals.admin.api.artifact.lifecycle.SharedLibraryLifecycle;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ArtifactDeployedException;
import org.ow2.petals.admin.api.exception.ArtifactNotDeployedException;
import org.ow2.petals.admin.api.exception.ArtifactNotFoundException;
import org.ow2.petals.admin.api.exception.ArtifactStartedException;
import org.ow2.petals.admin.api.exception.ArtifactStoppedException;
import org.ow2.petals.admin.jmx.JMXClientConnection;
import org.ow2.petals.jmx.JMXClient;
import org.ow2.petals.jmx.exception.ConnectionErrorException;
import org.ow2.petals.jmx.exception.InstallationServiceDoesNotExistException;
import org.ow2.petals.jmx.exception.InstallationServiceErrorException;

/**
 * This class represents a remote JBI shared library.
 * 
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class JMXSharedLibraryLifecycle extends SharedLibraryLifecycle {

    protected JMXSharedLibraryLifecycle(SharedLibrary sl) {
        super(sl);
    }

    @Override
    public void deploy(URL artifactUrl) throws ArtifactDeployedException,
            ArtifactAdministrationException {
        try {
            JMXClient client = JMXClientConnection.getJMXClient();
            client.getInstallationServiceClient().installSharedLibrary(artifactUrl);
        } catch (ConnectionErrorException cee) {
            throw new ArtifactAdministrationException(cee);
        } catch (InstallationServiceErrorException isee) {
            throw new ArtifactAdministrationException(isee);
        } catch (InstallationServiceDoesNotExistException isdnee) {
            throw new ArtifactAdministrationException(isdnee);
        }
    }

    @Override
    public void undeploy() throws ArtifactStartedException, ArtifactNotFoundException,
            ArtifactAdministrationException {
        JMXClient client = null;

        try {
            client = JMXClientConnection.getJMXClient();
            String slName = this.getSharedLibrary().getName();
            boolean isSuccessful = client.getInstallationServiceClient().uninstallSharedLibrary(
                    slName);
            if (!isSuccessful) {
                String errorMessage = String.format("Failed to uninstall the SL '%s'", slName);
                throw new ArtifactAdministrationException(errorMessage.toString());
            }
        } catch (ConnectionErrorException cee) {
            throw new ArtifactAdministrationException(cee);
        } catch (InstallationServiceErrorException isee) {
            throw new ArtifactAdministrationException(isee);
        } catch (InstallationServiceDoesNotExistException isdnee) {
            throw new ArtifactAdministrationException(isdnee);
        }
    }

    @Override
    public void updateState() throws ArtifactAdministrationException {
    }

    @Override
    public void start() throws ArtifactStartedException, ArtifactNotDeployedException,
            ArtifactNotFoundException, ArtifactAdministrationException {
    }

    @Override
    public void stop() throws ArtifactStoppedException, ArtifactNotDeployedException,
            ArtifactNotFoundException, ArtifactAdministrationException {
    }
}
